@@ -4,20 +4,18 @@ if(missing(Nrs) || missing(MC) || missing(fit))
 stop("Nrs, MC and/or fit missing.")
 
 for(n in Nrs){
-if(all(n!=n[1])){
+if(any(n!=n[1])){
 warning("Unequal number of reads across samples.")
 break
 }
 }
 
-MCC <- as.matrix(seq(1, 1, length=MC))
-Nrs <- t(t(Nrs))
+Xsc <- rep(0, MC)
+for(i in 1:MC)
+Xsc[i] <- Xsc.statistics.Hnull.Ha(Nrs, fit, type, pi0)
 
-Xsc <- t(t(apply(MCC, 1, function(x){Xsc.statistics.Hnull.Ha(Nrs, fit, type, pi0)})))
-Xsc_pval <- apply(Xsc, 2, function(t){
 q.alpha <- qchisq(p=(1-siglev), df=length(fit$pi)-1, ncp=0, lower.tail=TRUE)
-sum((t[t!="NaN"]>q.alpha)/(sum(t!="NaN")))
-})
+Xsc_pval <- sum((Xsc[Xsc != "NaN"] > q.alpha)/(sum(Xsc != "NaN")))
 
 return(Xsc_pval)
 }
