@@ -1,13 +1,12 @@
 Xdc.statistics.Hnull.Ha <-
 function(alphap, Nrs, n.groups, type, est){
-group.data.null <- list()
-index <- as.matrix(seq(1:n.groups))
+group.data.null <- vector("list", n.groups)
 
 if(tolower(type) == "hnull"){
-for(x in index)
+for(x in 1:n.groups)
 group.data.null[[x]] <- Dirichlet.multinomial(Nrs[[x]], shape=alphap)
 }else if(tolower(type) == "ha"){
-for(x in index)
+for(x in 1:n.groups)
 group.data.null[[x]] <- Dirichlet.multinomial(Nrs[[x]], shape=alphap[x,]) 
 }else{
 stop(sprintf("Type '%s' not found. Type must be 'ha' for power or 'hnull' for size.\n", as.character(type)))
