@@ -1,18 +1,17 @@
 Xmc.statistics.Hnull.Ha <-
 function(K, pi0, group.parameter){
-n.groups <- length(group.parameter)
-index <- as.matrix(seq(1:n.groups))
-group.parameter.estimated <- list()
+numGroups <- length(group.parameter)
+group.parameter.estimated <- vector("list", numGroups)
 
-for(x in index){
+for(x in 1:numGroups){
 pi <- group.parameter[[x]][1:K]
 theta <- group.parameter[[x]][K+1]
 P <- length(group.parameter[[x]])
 nreads.data <- as.matrix(group.parameter[[x]][(K+2):P])
 data <- Dirichlet.multinomial(nreads.data, shape=pi*(1-theta)/theta)
 
-pi.MoM <- apply(data, 2, sum)/sum(apply(data, 2, sum))
-theta.MoM <- weirMoM(data)
+pi.MoM <- colSums(data)/sum(colSums(data))
+theta.MoM <- weirMoM(data, pi.MoM)
 
 group.parameter.estimated[[x]] <- c(pi.MoM, theta.MoM, t(nreads.data))
 }
